/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.warehouse.materialloss.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.modules.warehouse.materialloss.entity.MaterialLoss;
import com.jeeplus.modules.warehouse.materialloss.mapper.MaterialLossMapper;
import com.jeeplus.modules.warehouse.materialloss.entity.MaterialLossInfo;
import com.jeeplus.modules.warehouse.materialloss.mapper.MaterialLossInfoMapper;

/**
 * 物资盘亏记录Service
 * @author zhanglt
 * @version 2023-02-14
 */
@Service
@Transactional(readOnly = true)
public class MaterialLossService extends CrudService<MaterialLossMapper, MaterialLoss> {

	@Autowired
	private MaterialLossInfoMapper materialLossInfoMapper;
	
	public MaterialLoss get(String id) {
		MaterialLoss materialLoss = super.get(id);
		materialLoss.setMaterialLossInfoList(materialLossInfoMapper.findList(new MaterialLossInfo(materialLoss)));
		return materialLoss;
	}
	
	public List<MaterialLoss> findList(MaterialLoss materialLoss) {
		return super.findList(materialLoss);
	}
	
	public Page<MaterialLoss> findPage(Page<MaterialLoss> page, MaterialLoss materialLoss) {
		return super.findPage(page, materialLoss);
	}
	
	@Transactional(readOnly = false)
	public void save(MaterialLoss materialLoss) {
		super.save(materialLoss);
		for (MaterialLossInfo materialLossInfo : materialLoss.getMaterialLossInfoList()){
			if (materialLossInfo.getId() == null){
				continue;
			}
			if (MaterialLossInfo.DEL_FLAG_NORMAL.equals(materialLossInfo.getDelFlag())){
				if (StringUtils.isBlank(materialLossInfo.getId())){
					materialLossInfo.setMaterialLoss(materialLoss);
					materialLossInfo.preInsert();
					materialLossInfoMapper.insert(materialLossInfo);
				}else{
					materialLossInfo.setMaterialLoss(materialLoss);
					materialLossInfo.preUpdate();
					materialLossInfoMapper.update(materialLossInfo);
				}
			}else{
				materialLossInfoMapper.delete(materialLossInfo);
			}
		}
	}
	
	@Transactional(readOnly = false)
	public void delete(MaterialLoss materialLoss) {
		super.delete(materialLoss);
		materialLossInfoMapper.delete(new MaterialLossInfo(materialLoss));
	}
	
}